/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.entity.common;

import java.util.ArrayList;
import java.util.List;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

/**
 * 模型的属性
 * 
 * @author luoguo
 * 
 */
@XStreamAlias("field")
public class Field {

	/**
	 * 标准字段名，用于引用标准字段
	 */
	@XStreamAsAttribute
	@XStreamAlias("standard-field-id")
	private String standardFieldId;
	/**
	 * 是否主键
	 */
	@XStreamAsAttribute
	private boolean primary;
	/**
	 * 是否唯一
	 */
	@XStreamAsAttribute
	private boolean unique;
	/**
	 * 是否显示字段
	 */
	@XStreamAsAttribute
	private boolean display;

	@XStreamAsAttribute
	@XStreamAlias("validate-mode")
	String validateMode;// 输入时验证，提交时验证

	/**
	 * 验证规则，这个和校验框架对接，每种方式可以有种的属性
	 */
	@XStreamAlias("validate-rules")
	private List<ValidateRule> validateRules;
	/**
	 * 实体名称，如果存在，就表示是引用自另外的模型引用
	 */
	@XStreamAsAttribute
	@XStreamAlias("model-id")
	private String modelId;
	/**
	 * 字段标识，可以不设置，不设置则取值与standardFieldId相同
	 */
	@XStreamAsAttribute
	private String id;
	@XStreamAsAttribute
	@XStreamAlias("alise-name")
	private String aliseName;// 别名

	public String getValidateMode() {
		return validateMode;
	}

	public void setValidateMode(String validateMode) {
		this.validateMode = validateMode;
	}

	public String getAliseName() {
		return aliseName;
	}

	public void setAliseName(String aliseName) {
		this.aliseName = aliseName;
	}

	public String getModelId() {
		return modelId;
	}

	public void setModelId(String modelId) {
		this.modelId = modelId;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getStandardFieldId() {
		return standardFieldId;
	}

	public void setStandardFieldId(String standardFieldId) {
		this.standardFieldId = standardFieldId;
	}

	public boolean isPrimary() {
		return primary;
	}

	public void setPrimary(boolean primary) {
		this.primary = primary;
	}

	public boolean isUnique() {
		return unique;
	}

	public void setUnique(boolean unique) {
		this.unique = unique;
	}

	public boolean isDisplay() {
		return display;
	}

	public void setDisplay(boolean display) {
		this.display = display;
	}

	public List<ValidateRule> getValidateRules() {
		if (validateRules == null)
			validateRules = new ArrayList<ValidateRule>();
		return validateRules;
	}

	public void setValidateRules(List<ValidateRule> validateRules) {
		this.validateRules = validateRules;
	}

}
