/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.entity.common;

import java.util.ArrayList;
import java.util.List;

import org.tinygroup.entity.base.BaseObject;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

@XStreamAlias("operation")
public class Operation extends BaseObject {
	@XStreamAsAttribute
	Boolean confirm;// 是否确认后再真正执行
	@XStreamAsAttribute
	String templete;// 渲染模板,如果不指定则表示用默认处理方式
	@XStreamAsAttribute
	String url;// 提交地址,如果不指定，则表示提交到默认URL

	@XStreamAlias("condition-fields")
	List<ConditionField> conditionFields;// 条件字段
	@XStreamAlias("operation-groups")
	List<OperationGroup> operationGroups;// 操作分组
	@XStreamAsAttribute
	String type;// 操作类型，可以是新增，删除，更新，查看等等
	@XStreamAsAttribute
	@XStreamAlias("operation-record-mode")
	String operationRecordMode;// 操作记录的方式，可以是None(无),Single(单记录),Multiple(多记录)
	@XStreamAsAttribute
	@XStreamAlias("before-services")
	String beforeServices;// 前置服务列表,如果有多个用逗号分隔
	@XStreamAsAttribute
	@XStreamAlias("after-services")
	String afterServices;// 后置服务列表,如果有多个用逗号分隔
	@XStreamAsAttribute
	@XStreamAlias("display-mode")
	String displayMode;//显示方式，弹出，页面切换,Left,Right,Top,Bottom
	
	@XStreamAsAttribute
	@XStreamAlias("permission-check")
	Boolean permissionCheck;// 是否进行权限检查，如果需要权限检查，则会自动注册权限，并进行权限校验

	public Boolean getPermissionCheck() {
		return permissionCheck;
	}

	public void setPermissionCheck(Boolean permissionCheck) {
		this.permissionCheck = permissionCheck;
	}

	public String getDisplayMode() {
		return displayMode;
	}

	public void setDisplayMode(String displayMode) {
		this.displayMode = displayMode;
	}

	public String getBeforeServices() {
		return beforeServices;
	}

	public void setBeforeServices(String beforeServices) {
		this.beforeServices = beforeServices;
	}

	public String getAfterServices() {
		return afterServices;
	}

	public void setAfterServices(String afterServices) {
		this.afterServices = afterServices;
	}

	public String getOperationRecordMode() {
		return operationRecordMode;
	}

	public void setOperationRecordMode(String operationRecordMode) {
		this.operationRecordMode = operationRecordMode;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Boolean getConfirm() {
		return confirm;
	}

	public void setConfirm(Boolean confirm) {
		this.confirm = confirm;
	}

	public String getTemplete() {
		return templete;
	}

	public void setTemplete(String templete) {
		this.templete = templete;
	}

	public List<ConditionField> getConditionFields() {
		if (conditionFields == null)
			conditionFields = new ArrayList<ConditionField>();
		return conditionFields;
	}

	public void setConditionFields(List<ConditionField> conditionFields) {
		this.conditionFields = conditionFields;
	}

	public List<OperationGroup> getOperationGroups() {
		if (operationGroups == null)
			operationGroups = new ArrayList<OperationGroup>();
		return operationGroups;
	}

	public void setOperationGroups(List<OperationGroup> operationGroups) {
		this.operationGroups = operationGroups;
	}

}
