/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.entity.common;

import java.util.ArrayList;
import java.util.List;

import org.tinygroup.entity.base.BaseObject;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

@XStreamAlias("view")
public class View extends BaseObject {
	@XStreamAsAttribute
	String style;// 显示风格，卡片式，树状，树表，表格，图表，等等
	// 条件属性
	@XStreamAlias("condition-fields")
	List<ConditionField> conditionFields;
	// 分类属性
	@XStreamAlias("category-fields")
	List<CategoryField> categoryFields;
	// 视图属性，视图字段分组
	@XStreamAlias("view-groups")
	List<ViewGroup> viewGroups;
	// 排序属性 order by
	@XStreamAlias("order-fields")
	List<OrderField> orderFields;
	// group by
	@XStreamAlias("group-fields")
	List<GroupField> groupFields;
	@XStreamAsAttribute
	String templete;// 显示模板
	List<String> operations;// operationuuid list
	@XStreamAsAttribute
	@XStreamAlias("top-paging-bar")
	Boolean topPagingBar;// 是否显示分布框
	@XStreamAsAttribute
	@XStreamAlias("bottom-paging-bar")
	Boolean bottomPagingBar;// 是否显示分布框
	@XStreamAlias("operation-references")
	List<OperationReference> operationReferences;// 关联操作

	@XStreamAlias("operation-views")
	List<ViewReference> operationViews;// 关联视图

	@XStreamAsAttribute
	@XStreamAlias("view-reference-position")
	String viewReferencePosition;// 视图引用放置位置，Top/Right/Top/Bottom

	@XStreamAsAttribute
	@XStreamAlias("permission-check")
	Boolean permissionCheck;// 是否进行权限检查，如果需要权限检查，则会自动注册权限，并进行权限校验

	public Boolean getPermissionCheck() {
		return permissionCheck;
	}

	public void setPermissionCheck(Boolean permissionCheck) {
		this.permissionCheck = permissionCheck;
	}

	public String getViewReferencePosition() {
		return viewReferencePosition;
	}

	public void setViewReferencePosition(String viewReferencePosition) {
		this.viewReferencePosition = viewReferencePosition;
	}

	public List<ViewReference> getOperationViews() {
		return operationViews;
	}

	public void setOperationViews(List<ViewReference> operationViews) {
		this.operationViews = operationViews;
	}

	public List<OperationReference> getOperationReferences() {
		return operationReferences;
	}

	public void setOperationReferences(
			List<OperationReference> operationReferences) {
		this.operationReferences = operationReferences;
	}

	public Boolean getTopPagingBar() {
		return topPagingBar;
	}

	public void setTopPagingBar(Boolean topPagingBar) {
		this.topPagingBar = topPagingBar;
	}

	public Boolean getBottomPagingBar() {
		return bottomPagingBar;
	}

	public void setBottomPagingBar(Boolean bottomPagingBar) {
		this.bottomPagingBar = bottomPagingBar;
	}

	public String getStyle() {
		return style;
	}

	public void setStyle(String style) {
		this.style = style;
	}

	public List<ConditionField> getConditionFields() {
		if (conditionFields == null)
			conditionFields = new ArrayList<ConditionField>();
		return conditionFields;
	}

	public void setConditionFields(List<ConditionField> conditionFields) {
		this.conditionFields = conditionFields;
	}

	public List<CategoryField> getCategoryFields() {
		if (categoryFields == null)
			categoryFields = new ArrayList<CategoryField>();
		return categoryFields;
	}

	public void setCategoryFields(List<CategoryField> categoryFields) {
		this.categoryFields = categoryFields;
	}

	public List<ViewGroup> getViewGroups() {
		if (viewGroups == null)
			viewGroups = new ArrayList<ViewGroup>();
		return viewGroups;
	}

	public void setViewGroups(List<ViewGroup> viewGroups) {
		this.viewGroups = viewGroups;
	}

	public List<OrderField> getOrderFields() {
		if (orderFields == null)
			orderFields = new ArrayList<OrderField>();
		return orderFields;
	}

	public void setOrderFields(List<OrderField> orderFields) {
		this.orderFields = orderFields;
	}

	public List<GroupField> getGroupFields() {
		if (groupFields == null)
			groupFields = new ArrayList<GroupField>();
		return groupFields;
	}

	public void setGroupFields(List<GroupField> groupFields) {
		this.groupFields = groupFields;
	}

	public String getTemplete() {
		return templete;
	}

	public void setTemplete(String templete) {
		this.templete = templete;
	}

	public List<String> getOperations() {
		if (operations == null)
			operations = new ArrayList<String>();
		return operations;
	}

	public void setOperations(List<String> operations) {
		this.operations = operations;
	}

}
