/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.entity.ralation;

import org.tinygroup.entity.base.BaseObject;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

/**
 * 实体关系<br>
 * 比如表结构如下：<br>
 * ----------------------------------<br>
 * org<br>
 * org_id|org_name|org_desc<br>
 * user<br>
 * user_id|user_name|org_id|user_desc<br>
 * ----------------------------------<br>
 * 则关联关系为： <entity-ralation source-entity-id="user" dest-entity-id="org"
 * foreign-key-field-id="org_id" /><br>
 * 
 */
@XStreamAlias("entity-ralation")
public class EntityRalation extends BaseObject {
	@XStreamAsAttribute
	@XStreamAlias("source-entity-id")
	String sourceEntityId;// 源实体模型标识
	@XStreamAsAttribute
	@XStreamAlias("dest-entity-id")
	String destEntityId;// 目标实体模型标识
	@XStreamAsAttribute
	@XStreamAlias("foreign-key-field-id")
	String foreignKeyFieldId;// 外键字段标识

	public String getSourceEntityId() {
		return sourceEntityId;
	}

	public void setSourceEntityId(String sourceEntityId) {
		this.sourceEntityId = sourceEntityId;
	}

	public String getDestEntityId() {
		return destEntityId;
	}

	public void setDestEntityId(String destEntityId) {
		this.destEntityId = destEntityId;
	}

	public String getForeignKeyFieldId() {
		return foreignKeyFieldId;
	}

	public void setForeignKeyFieldId(String foreignKeyFieldId) {
		this.foreignKeyFieldId = foreignKeyFieldId;
	}

}
